<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="xml" indent="yes" doctype-system="DTD/design-specification.dtd"  encoding="UTF-8"/>
  <xsl:param name="pXml1"/>
  <xsl:param name="pXml2"/>
  <xsl:param name="pXml3"/>
  <xsl:param name="pXml4"/>
  <xsl:param name="pRoot"/>
  <xsl:template match="/">
    <xsl:variable name="vXml1" select="$pXml1"/>
    <xsl:variable name="vXml2" select="$pXml2"/>
    <xsl:variable name="vXml3" select="$pXml3"/>
    <xsl:variable name="vXml4" select="$pXml4"/>
    <xsl:element name="design-specification">
      <xsl:attribute name="receive-num"/>
      <xsl:attribute name="receive-date"/>
      <xsl:attribute name="dtd-version">2.0.1</xsl:attribute>
      <xsl:attribute name="application-num"/>
      <xsl:attribute name="status">n</xsl:attribute>
      <xsl:attribute name="produced-by">applicant</xsl:attribute>
      <description>
        <xsl:apply-templates select="$vXml2/design-specification-description/tw-design-title"/>
        <xsl:apply-templates select="$vXml2/design-specification-description/en-design-title"/>
        <xsl:apply-templates select="$vXml2/design-specification-description/main-use"/>
        <xsl:apply-templates select="$vXml2/design-specification-description/description-of-drawings"/>
      </description>
      <xsl:apply-templates select="$vXml4/design-specification-drawings"/>
    </xsl:element>
  </xsl:template>

  <xsl:template match="tw-design-title">
    <design-title lang="tw">
      <xsl:value-of select="."/>
    </design-title>
  </xsl:template>
  
  <xsl:template match="en-design-title">
    <design-title lang="en">
      <xsl:value-of select="."/>
    </design-title>
  </xsl:template>

  <xsl:template match="main-use">
    <xsl:element name="main-use">
      <xsl:apply-templates select="*|text()"/>
    </xsl:element>
  </xsl:template>

  <xsl:template match="description-of-drawings">
    <xsl:element name="description-of-drawings">
      <xsl:apply-templates select="*|text()"/>
    </xsl:element>
  </xsl:template>

  <xsl:template match="p">
    <p>
      <xsl:attribute name="general">
        <xsl:value-of select="@general"/>
      </xsl:attribute>
      <xsl:apply-templates select="*|text()"/>
    </p>
  </xsl:template>
  
  <xsl:template match="design-specification-drawings">
    <xsl:element name="drawings">
      <xsl:attribute name="lang"/>
      <xsl:apply-templates select="*|text()"/>
    </xsl:element>
  </xsl:template>
  
  <xsl:template match="figure">
    <xsl:element name="figure">
      <xsl:attribute name="figure-labels">
        <xsl:value-of select="@figure-labels"/>
      </xsl:attribute>
      <xsl:apply-templates select="img"/>
    </xsl:element>
  </xsl:template>
  
  <xsl:template match="img">
    <xsl:element name="img">
      <xsl:attribute name="he">
        <xsl:value-of select="@he"/>
      </xsl:attribute>
      <xsl:attribute name="wi">
        <xsl:value-of select="@wi"/>
      </xsl:attribute>
      <xsl:attribute name="file">
        <xsl:value-of select="@file"/>
      </xsl:attribute>
      <xsl:attribute name="img-format">
        <xsl:value-of select="@img-format"/>
      </xsl:attribute>
      <xsl:attribute name="id">
        <xsl:text>i</xsl:text>
        <xsl:number value="count(../preceding-sibling::*) + 1" format="0001"/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>
  <xsl:template match="br">
    <xsl:apply-templates select="*|text()"/>
    <br/>
  </xsl:template>
  <xsl:template match="i">
    <i>
      <xsl:apply-templates select="*|text()"/>
    </i>
  </xsl:template>
  
  <xsl:template match="u">
    <u>
      <xsl:apply-templates select="*|text()"/>
    </u>
  </xsl:template>
  
  <xsl:template match="b">
    <b>
      <xsl:apply-templates select="*|text()"/>
    </b>
  </xsl:template>
  
  <xsl:template match="s">
    <s>
      <xsl:apply-templates select="*|text()"/>
    </s>
  </xsl:template>
  
  <xsl:template match="sup">
    <sup>
      <xsl:apply-templates select="*|text()"/>
    </sup>
  </xsl:template>
  
  <xsl:template match="sub">
    <sub>
      <xsl:apply-templates select="*|text()"/>
    </sub>
  </xsl:template>
  <xsl:template match="tables">
    <tables>
      <xsl:attribute name="num"/>
      <xsl:apply-templates select="*|text()"/>
    </tables>
  </xsl:template>
  <xsl:template match="table|tr">
    <xsl:copy>
      <xsl:apply-templates select="node()"/>
    </xsl:copy>
  </xsl:template>
  <xsl:template match="td">
    <xsl:copy-of select="." />
  </xsl:template>
</xsl:stylesheet>
